SystemOrganization addCategory: #'Seaside-Tests-Email'!

!GRPackage class methodsFor: '*seaside-tests-email' stamp: 'lr 2/17/2010 15:13'!
seasideTestsEmail
	^ self new
		name: 'Seaside-Tests-Email';
		description: 'Unit tests for the package Seaside-Email.';
		addDependency: 'Seaside-Email';
		addDependency: 'Seaside-Tests-Core';
		url: #seasideUrl;
		yourself! !

TestCase subclass: #WAEmailMessageTest
	instanceVariableNames: 'message'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Email'!

!WAEmailMessageTest methodsFor: 'tests' stamp: 'PaulDeBruicker 10/25/2013 13:22'!
messageClass
	^ WAEmailMessage! !

!WAEmailMessageTest methodsFor: 'private' stamp: 'lr 7/25/2011 19:53'!
philippeMarschall
	^ WAEmailAddress
		address: 'philippe.marschall@gmail.com'
		username: 'Philippe Marschall'! !

!WAEmailMessageTest methodsFor: 'private' stamp: 'lr 7/25/2011 19:53'!
seasideDev
	^ WAEmailAddress
		address: 'seaside-dev@lists.squeakfoundation.org'
		username: 'Seaside Developers Mailinglist'! !

!WAEmailMessageTest methodsFor: 'tests' stamp: 'PaulDeBruicker 10/25/2013 13:21'!
setUp
	super setUp.
	message := self messageClass from: self philippeMarschall to: self seasideDev subject: 'new email package'.
	message setStringBody: 'Hello' wrap: false! !

!WAEmailMessageTest methodsFor: 'tests' stamp: 'topa 10/7/2010 09:39'!
testFromToSubjectBody
	| message cr |
	cr := String with: Character cr.
	message := WAEmailMessage
		from: self philippeMarschall
		to: self seasideDev
		subject: 'new email package'.
	message setStringBody: 'Hello' wrap: false.
	"we don't test them here: "
	message headers removeKey: 'Date'.
		
	self assert:
'From: "Philippe Marschall" <philippe.marschall@gmail.com>', cr,
'To: "Seaside Developers Mailinglist" <seaside-dev@lists.squeakfoundation.org>',cr ,
'Subject: new email package', cr, cr,
'Hello' = message plainMessage! !

!WAEmailMessageTest methodsFor: 'tests' stamp: 'PaulDeBruicker 10/25/2013 13:25'!
testHeaders
	| cr now |
	cr := String with: Character cr.
	now := GRPrinter rfc822 print: DateAndTime now.
	message replyTo: self philippeMarschall.
	message headerAt: 'Date' put: now.	" We have to take into account, that the header order is not implied."
	self
		assert:
			(('From: "Philippe Marschall" <philippe.marschall@gmail.com>' , cr
				, 'To: "Seaside Developers Mailinglist" <seaside-dev@lists.squeakfoundation.org>' , cr
				, 'Subject: new email package' , cr , 'Date: ' , now , cr
				, 'Reply-To: "Philippe Marschall" <philippe.marschall@gmail.com>' , cr , cr , 'Hello') = message plainMessage
				or: [ 
					('From: "Philippe Marschall" <philippe.marschall@gmail.com>' , cr
						, 'To: "Seaside Developers Mailinglist" <seaside-dev@lists.squeakfoundation.org>' , cr
						, 'Subject: new email package' , cr , 'Reply-To: "Philippe Marschall" <philippe.marschall@gmail.com>' , cr
						, 'Date: ' , now , cr , cr , 'Hello') = message plainMessage ])! !

WAEmailMessageTest subclass: #WAMultiPartEmailMessageTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Email'!

!WAMultiPartEmailMessageTest methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2013 13:27'!
messageClass
	^ WAMultiPartEmailMessage! !

!WAMultiPartEmailMessageTest methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2013 13:34'!
testFromToSubjectBody
	| cr |
	cr := String with: Character cr.	"we don't test them here: "
	message headers removeKey: 'Date'.
	self
		assert:
			'From: "Philippe Marschall" <philippe.marschall@gmail.com>
To: "Seaside Developers Mailinglist" <seaside-dev@lists.squeakfoundation.org>
Subject: new email package
Content-Type: multipart/alternative; boundary=' , message boundary
				,
					'


--' , message boundary
				,
					'
Content-Type: text/plain; charset=UTF-8

Hello

--' , message boundary
				,
					'--
'
		equals: message plainMessage! !

!WAMultiPartEmailMessageTest methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2013 13:34'!
testHeaders
	| cr now |
	cr := String with: Character cr.
	now := GRPrinter rfc822 print: DateAndTime now.
	message replyTo: self philippeMarschall.
	message headerAt: 'Date' put: now.	" We have to take into account, that the header order is not implied."
	self
		assert:
			(('From: "Philippe Marschall" <philippe.marschall@gmail.com>
To: "Seaside Developers Mailinglist" <seaside-dev@lists.squeakfoundation.org>
Subject: new email package
Reply-To: "Philippe Marschall" <philippe.marschall@gmail.com>
Date: ' , now
				,
					'
Content-Type: multipart/alternative; boundary=' , message boundary
				,
					'


--' , message boundary
				,
					'
Content-Type: text/plain; charset=UTF-8

Hello

--' , message boundary
				,
					'--
') = message plainMessage
				or: [ 
					('From: "Philippe Marschall" <philippe.marschall@gmail.com>
To: "Seaside Developers Mailinglist" <seaside-dev@lists.squeakfoundation.org>
Subject: new email package
Reply-To: "Philippe Marschall" <philippe.marschall@gmail.com>
Content-Type: multipart/alternative; boundary=' , message boundary
						,
							'
Date: ' , now
						,
							'


--' , message boundary
						,
							'
Content-Type: text/plain; charset=UTF-8

Hello

--' , message boundary
						,
							'--
') = message plainMessage ])! !

!WAMultiPartEmailMessageTest methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2013 13:43'!
testParts
	message setHtmlBody: [ :h | h paragraph: 'hello' ].
	self assert: message parts size equals: 2.
	self assert: message parts asArray sort last isHtml.
	self assert: message plainTextBodyString equals: 'Hello'.
	self assert: message htmlBodyString equals:'<html><head><title></title></head><body onload="onLoad()"><p>hello</p><script type="text/javascript">/*<!![CDATA[*/function onLoad(){};/*]]>*/</script></body></html>'! !

TestCase subclass: #WAHtmlEmailBodyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Email'!

!WAHtmlEmailBodyTest methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2013 13:16'!
testBasics
	| body |
	body := WAHtmlEmailBody
		renderingBlock: [ :h | 
			h anchor
				url: 'http://www.google.com';
				with: 'hello' ].
	self assert: body isHtml.
	self assert: body string equals: '<html><head><title></title></head><body onload="onLoad()"><a href="http://www.google.com">hello</a><script type="text/javascript">/*<!![CDATA[*/function onLoad(){};/*]]>*/</script></body></html>'.
	self assert: body contentType equals: 'text/html; charset=UTF-8'! !

TestCase subclass: #WAStringEmailBodyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Email'!

!WAStringEmailBodyTest methodsFor: 'tests' stamp: 'PaulDeBruicker 10/25/2013 13:15'!
testBasics
	| body |
	body := WAStringEmailBody string: 'hello'.
	self assert: body isPlainText.
	self assert: body string equals: 'hello'.
	self assert: body contentType equals: 'text/plain; charset=UTF-8'! !

!WAStringEmailBodyTest methodsFor: 'tests' stamp: 'jf 9/30/2009 01:10'!
testCrLf
	| cr lf crlf body |
	cr := String with: Character cr.
	lf := String with: Character lf.
	crlf := cr , lf.
	body := WAStringEmailBody string: 'hello' , crlf , 'world'.
	self assert: ('hello' , cr , 'world') = body greaseString! !

!WAStringEmailBodyTest methodsFor: 'tests' stamp: 'pmm 8/31/2008 19:00'!
testSplitIntoLines
	| cr toSplit actual |
	cr := String with: Character cr.
	
	toSplit := cr, cr, 'a', cr, cr.
	actual := WAStringEmailBody splitIntoLines: toSplit.
	self assert: actual size = 5.
	#('' '' 'a' '' '') keysAndValuesDo: [ :index :expected |
		self assert: (actual at: index) = expected ].
	
	toSplit := cr, cr, 'a', cr.
	actual := WAStringEmailBody splitIntoLines: toSplit.
	self assert: actual size = 4.
	#('' '' 'a' '') keysAndValuesDo: [ :index :expected |
		self assert: (actual at: index) = expected ].
	
	toSplit := cr, cr, 'a'.
	actual := WAStringEmailBody splitIntoLines: toSplit.
	self assert: actual size = 3.
	#('' '' 'a') keysAndValuesDo: [ :index :expected |
		self assert: (actual at: index) = expected ].! !

!WAStringEmailBodyTest methodsFor: 'tests' stamp: 'jf 9/30/2009 01:10'!
testWrapping
	| cr body lf crlf |
	cr := String with: Character cr.
	lf := String with: Character lf.
	crlf := cr , lf.
	body := WAStringEmailBody 
		string: '1111 222 2 33'
		lineLength: 5.
	self assert: ('1111' , cr , '222 2' , cr , '33') = body greaseString.
	body := WAStringEmailBody 
		string: '0123456789'
		lineLength: 5.
	self assert: ('01234' , cr , '56789') = body greaseString.
	body := WAStringEmailBody 
		string: '012345678'
		lineLength: 5.
	self assert: ('01234' , cr , '5678') = body greaseString.
	body := WAStringEmailBody 
		string: '01234567890'
		lineLength: 5.
	self assert: ('01234' , cr , '56789' , cr , '0') = body greaseString.
	body := WAStringEmailBody 
		string: '0123456789' , crlf , crlf , '0123456789'
		lineLength: 5.
	self assert: ('01234' , cr , '56789' , cr , cr , '01234' , cr , '56789') = body greaseString! !
